C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    M_PTOZSA    CONVERT A PRESSURE TO HEIGHT
C   PRGMMR: MIKE BARTH       ORG: FSL        DATE: 03-09-29
C
C ABSTRACT: FUNCTION TO CONVERTS A PRESSURE IN MILLIBARS TO A HEIGHT
C   IN METERS.  A STANDARD ATMOSPHERE IS ASSUMED.  THIS TYPE OF HEIGHT 
C   IS ALSO KNOWN AS "PRESSURE ALTITUDE".
C
C PROGRAM HISTORY LOG:
C   86-07-10  K. BREWSTER   ORIGINAL VERSION (PROBABLY BY KEITH)
C   8X-XX-XX  J. RAMER      COPIED FROM MAPS AND MODIFIED FOR AWIPS
C   03-09-29  M. BARTH      COPIED FROM AWIPS AND MODIFIED FOR MADIS
C   05-05-15  L. BENJAMIN   RAISE MAXIMUM HEIGHT TO 0.09 MILLIBARS
C
C USAGE:    M_PTOZSA(P)
C   INPUT ARGUMENT LIST:
C     P        - REAL   PRESSURE IN MILLIBARS.
C
C   OUTPUT ARGUMENT LIST:
C     M_PTOZSA - REAL   HEIGHT IN METERS.
C
C REMARKS:
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$
      REAL FUNCTION M_PTOZSA(P)
 
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'

      REAL T0,GAMMA,P0,P11,Z11,C1,C2,P,FLAG
 
      DATA FLAG/MISS_P/
      DATA T0,GAMMA,P0/288.,.0065,1013.2/
      DATA C1,C2/5.256,14600./
      DATA Z11,P11/11000.,226.0971/
 
      IF (P.GT.FLAG-1 .OR. P.LT.0.09) THEN
         M_PTOZSA=FLAG
      ELSE IF (P.GT.P11) THEN
         M_PTOZSA=((T0-T0*(P/P0)**(1/C1))/GAMMA)
      ELSE
         M_PTOZSA=(C2*ALOG10(P11/P)+Z11)
      END IF
 
      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
 
