C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MGETRAOB    GET RAOB OBS & QC FOR A VARIABLE
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-03-24
C
C ABSTRACT: READ RAOB OBS & QC INFO FOR ALL STATIONS FOR ONE VARIABLE
C   AND TIME.
C
C PROGRAM HISTORY LOG:
C   00-03-24  M. BARTH    ORIGINAL VERSION
C   01-07-26  M. BARTH    - CHANGE FROM CALLER-SPECIFIED VARIABLE CODE
C                           NUMBER TO VARIABLE CODE NAME
C                         - RETURN VAR_NOTINDB_P ERROR IF AWIPS 
C                           DATABASE & VARIABLE IS SONDE TYPE --
C                           IT'S IN THE FILE, BUT IT'S BOGUS...
C
C USAGE:    CALL MGETRAOB (ATIME,VCODE,NSTA,NOBS,NLEVELS,OB,QCDESC,
C                          QCAPP,QCRES,STATUS)
C
C   INPUT ARGUMENT LIST:
C     ATIME    - C       YYJJJHHMM OF THE DATA TO BE READ
C     VCODE    - C       VARIABLE CODE NAME
C
C   OUTPUT ARGUMENT LIST:
C     NSTA     - I       NUMBER OF STATIONS RETURNED
C     NOBS     - I       NUMBER OF NON-MISSING OBS
C     NLEVELS  - IA      NUMBER OF LEVELS
C     OB       - RA      OBSERVATIONS IN M/K/S UNITS
C     QCDESC   - CA      QC DATA DESCRIPTORS
C     QCAPP    - IA      QC APPLIED WORD (SHOWS CHECKS APPLIED)
C     QCRES    - IA      QC RESULTS WORD (GOOD/BAD FOR EACH CHECK)
C     STATUS   - I       0 - SUCCESS, OR ERROR CODE
C
C   INPUT FILES:
C     MADIS RAOB NETCDF FILES FOR ATIME
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MGETUAPT
C
C REMARKS:
C   - THE CALLER MUST CALL MINIT AND MRAOBSTA BEFORE CALLING THIS
C     ROUTINE.  MRAOBSTA SHOULD BE CALLED FIRST WHENEVER ACCESS TO
C     A NEW TIME IS DESIRED.  IT STORES INFO IN THE STRCCOM COMMON
C     THAT IS USED BY THIS ROUTINE TO FIGURE OUT WHICH RECORDS ARE
C     NEEDED ON NETCDF FILES OPENED BY MRAOBSTA.
C   - DOUBLE & CHARACTER DATA TYPES ARE NOT HANDLED BY THIS ROUTINE.
C   - THE CALLER SHOULD DIMENSION ARRAYS TO MATCH THE MAXIMUM NUMBER
C     OF LEVELS AND STATIONS POSSIBLE FOR THIS DATATYPE (madiscon.f).
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MGETRAOB(ATIME,VCODE,NSTA,NOBS,NLEVELS,OB,QCDESC,QCAPP,
     1                    QCRES,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*9 ATIME
      CHARACTER*(*) VCODE
      INTEGER NSTA,NOBS,NLEVELS(*),QCAPP(*),QCRES(*),STATUS
      REAL OB(*)
      CHARACTER*1 QCDESC(*)

C     ------------------------------------------------------------------
C     SET THE CURRENT DATATYPE TO RAOB, THEN LET THE UPPER-AIR-POINT
C     DATASET COMMON SUBROUTINE DO MOST OF THE WORK (UNLESS IT'S THE
C     SPECIAL CASE WHERE AWIPS DATABASE SONDE TYPES EXIST IN THE FILES
C     BUT ARE ALL 0'S, WHICH ARE BOGUS INFO...
C     ------------------------------------------------------------------
      CDTYPE = RAOB_DS_P

      IF(UAPT_DBTYPE(CDTYPE).EQ.AWIPS_DB_P.AND.
     1   VCODE(1:6).EQ.'SONDET')THEN

         STATUS = VAR_NOTINDB_P
         CALL MERROR('MGETRAOB: VARIABLE NOT IN SELECTED DATABASE')

      ELSE

         CALL MGETUAPT(ATIME,VCODE,NSTA,NOBS,NLEVELS,OB,QCDESC,QCAPP,
     1                 QCRES,STATUS)

      ENDIF

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
