C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MSATRADINIT INITIALIZE MADIS SATRAD DATA
C   PRGMMR: L. BENJAMIN      ORG: FSL        DATE: 04-09-27
C
C ABSTRACT: READ FILES TO GET PARAMETERS SPECIFYING WHAT WE NEED TO
C   KNOW TO READ NETCDF VARIABLES AND PROCESS THEM FOR SATRAD DATASETS,
C   AND FOR ANY OTHER INFO NEEDED ONE TIME FOR SATRAD PROCESSING.
C
C PROGRAM HISTORY LOG:
C   05-10-25  L. BENJAMIN ORIGINAL VERSION
C
C USAGE:    CALL MSATRADINIT (SATRADTBL,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     SATRADTBL- C       FILENAME OF THE MADIS SATRAD TABLE
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE CODE
C
C   INPUT FILES:
C     SATRADTBL- FILE SPECIFYING THE VARIABLES IN THE MADIS NETCDF 
C                FILES
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MSATRADTBL
C
C REMARKS:
C   - LIMITED ERROR CHECKING IS DONE ON THE TABLE, AS IT'S MEANT TO
C     BE STATIC AND CREATED AT CODE DEVELOPMENT TIME.
C   - THE MADISCOM PROVIDER ARRAYS (NPVD, PVDNAME, ETC.) HAVE SATRAD
C     PROVIDERS IN ROW 1, HYDRO PROVIDERS IN ROW 2, MAP PROVIDERS
C     IN ROW 3, RDMTR PROVIDERS IN ROW 4, SATWND PROVIDERS IN ROW 5.
C     SATSND PROVIDERS IN ROW 6, AND SATRAD PROVIDERS IN ROW 7.
C   - THE DEFAULT PROVIDER SELECTION IS 'ALL-POES', FOR BOTH POES
C     SATELLITES, OPERATIONAL PRODUCTS.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MSATRADINIT(SATRADTBL,STATUS)

C     INCLUDES AND COMMONS
C     -----------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     -----------------------------------------------------------------
C     ARGUMENTS
C     -----------------------------------------------------------------
      CHARACTER*(*) SATRADTBL
      INTEGER       STATUS

C     -----------------------------------------------------------------
C     LOCAL
C     -----------------------------------------------------------------
      INTEGER       I

C     ---------------------------------------------------------------
C     INITIALIZE MADISCOM VARIABLES.  NOTE THAT THE DEFAULT PROVIDER
C     SELECTION IS ALL-POES (POES SATELLITES, OPERATIONAL
C     PRODUCTS).  BECAUSE OF THE SIZE OF THE SATELLITE DATASETS WE
C     DON'T ENABLE EVERYTHING BY DEFAULT.
C     ---------------------------------------------------------------
      DO I = 1, MAX_SATRDSET_P
         SATRDSET_ENBL(I) = .FALSE.
      ENDDO
      SATRDSET_ENBL(1) = .TRUE.
      DO 1201 I = 1, MAX_SUBSRC_P
         PROVDR_ENBL(I,7) = .TRUE.
 1201 CONTINUE

      NNEWPVD(7) = 0
      ALL_ENBL(7) = .TRUE.

      SATRDSET_NAME(1) = 'SATELLITE-RADIANCE'

      LAST_SATR_ATIME = '         '

      TOTAL_STNS = 0
      DMTYPE = -1
      QCTYPE = 0

      MINBCK = 0
      MINFWD = 0
      RECWIN = 0

      SATR_INIT = INIT_P

C     -----------------------------------------------------------------
C     READ IN THE MADIS SATRAD TABLE (DEFINES VARIABLES AND DATASETS).
C     MSATRADTBL WILL REPORT ANY ERRORS AND SET STATUS.
C     -----------------------------------------------------------------
      CALL MSATRADTBL(SATRADTBL,STATUS)
      IF(STATUS.NE.SUCCESS_P)RETURN

      RETURN
      END
C**--------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**--------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**--------------------------------------------------------------------
