C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MUAPTINIT   INITIALIZE MADIS UPPER-AIR-POINT DATA
C   PRGMMR: M. BARTH         ORG: FSL        DATE: 00-03-23
C
C ABSTRACT: READ FILE TO GET PARAMETERS SPECIFIYING WHAT WE NEED TO
C   KNOW TO READ NETCDF VARIABLES AND PROCESS THEM FOR THE SELECTED
C   UPPER-AIR-POINT DATASET, AND FOR ANY OTHER INFO NEEDED ONE TIME
C   FOR PROCESSING THE DATASET.
C
C PROGRAM HISTORY LOG:
C   00-03-23  M. BARTH    ORIGINAL VERSION
C   02-04-30  M. BARTH    ADDED MAP DATASET AND SUBSRCIN ARGUMENT
C   03-05-27  M. BARTH    - REMOVED SUBSRCIN ARGUMENT AND RELATED WORK
C                         - INITIALIZE DATA STRUCTURES THAT TRACK NEW
C                           PROVIDERS
C   03-07-01  M. BARTH    ADDED RDMTR DATASET
C   04-06-16  M. BARTH    ADDED ACARSP DATASET
C
C USAGE:    CALL MUAPTINIT (UAPTTBL,STATUS)
C
C   INPUT ARGUMENT LIST:
C     UAPT_TYPE- I       CODE NUMBER FOR THIS DATASET
C     UAPTTBL  - C       FILENAME OF THE MADIS TABLE FOR THIS DATASET
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE CODE
C
C   INPUT FILES:
C     UAPTTBL  - FILE SPECIFYING THE VARIABLES IN THE MADIS NETCDF FILES
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MUAPTTBL
C
C REMARKS:
C   - LIMITED ERROR CHECKING IS DONE ON THE TABLE, AS IT'S MEANT TO
C     BE STATIC AND CREATED AT CODE DEVELOPMENT TIME.
C   - THE MADISCOM PROVIDER ARRAYS (NPVD, PVDNAME, ETC.) HAVE SFC
C     PROVIDERS IN ROW 1, HYDRO PROVIDERS IN ROW 2, MAP PROVIDERS
C     ROW 3, RDMTR PROVIDERS IN ROW 4.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MUAPTINIT(UAPT_TYPE,UAPTTBL,STATUS)

C     ------------------------------------------------------------------
C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      INTEGER       UAPT_TYPE
      CHARACTER*(*) UAPTTBL
      INTEGER       STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER       I,J

C     ---------------------------------------------------------------
C     INITIALIZE MADISCOM VARIABLES.
C     ---------------------------------------------------------------
      UAPTDSET_NAME(1) = 'RAOB     '
      UAPTDSET_NAME(2) = 'NPN      '
      UAPTDSET_NAME(3) = 'ACARS    '
      UAPTDSET_NAME(4) = 'MAP      '
      UAPTDSET_NAME(5) = 'RDMTR    '
      UAPTDSET_NAME(6) = 'ACARSP   '

      LAST_UAPT_ATIME(UAPT_TYPE) = '         '

      DMTYPE = -1
      QCTYPE = 0
      VCTYPE = 0
      CORTYP = 0

      MINBCK = 0
      MINFWD = 0
      RECWIN = 0

      UAPT_INIT(UAPT_TYPE) = INIT_P

C     ------------------------------------------------------------------
C     FOR MAP OR RDMTR, INDICATE THAT ALL PROVIDERS ARE ENABLED.
C     ------------------------------------------------------------------
      IF(UAPT_TYPE.EQ.MAP_DS_P.OR.UAPT_TYPE.EQ.RDMTR_DS_P)THEN

         IF(UAPT_TYPE.EQ.MAP_DS_P)THEN
            J = 3
         ELSE IF(UAPT_TYPE.EQ.RDMTR_DS_P)THEN
            J = 4
         ENDIF
            
         DO 1201 I = 1, MAX_SUBSRC_P
            PROVDR_ENBL(I,J) = .TRUE.
 1201    CONTINUE

         NNEWPVD(J) = 0
         ALL_ENBL(J) = .TRUE.

      ENDIF

C     ------------------------------------------------------------------
C     READ IN THE MADIS TABLE FOR THIS UPPER-AIR-POINT DATASET
C     (DEFINES VARIABLES AND DATASETS).  MUAPTTBL WILL REPORT ANY ERRORS
C     AND SET STATUS.
C     ------------------------------------------------------------------
      CALL MUAPTTBL(UAPT_TYPE,UAPTTBL,STATUS)

      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
