C$$$  SUBPROGRAM DOCUMENTATION BLOCK
C                .      .    .                                       .
C SUBPROGRAM:    MWISDOMINIT INITIALIZE MADIS WISDOM DATA
C   PRGMMR: L. BENJAMIN      ORG: FSL        DATE: 08-07-18
C
C ABSTRACT: READ FILES TO GET PARAMETERS SPECIFIYING WHAT WE NEED TO
C   KNOW TO READ NETCDF VARIABLES AND PROCESS THEM FOR WISDOM DATASETS,
C   AND FOR ANY OTHER INFO NEEDED ONE TIME FOR WISDOM PROCESSING.
C
C PROGRAM HISTORY LOG:
C   08-07-18  L. BENJAMIN  ORIGINAL VERSION
C
C USAGE:    CALL MWISDOMINIT (WISDOMTBL,STATUS)
C
C   INPUT ARGUMENT LIST:
C
C     WISDOMTBL- C       FILENAME OF THE MADIS WISDOM TABLE
C
C   OUTPUT ARGUMENT LIST:
C     STATUS   - I       SUCCESS_P OR FAILURE CODE
C
C   INPUT FILES:
C     WISDOMTBL- FILE SPECIFYING THE VARIABLES IN THE MADIS NETCDF FILES
C
C SUBPROGRAMS CALLED:
C     UNIQUE:    MWISDOMTBL
C
C REMARKS:
C   - LIMITED ERROR CHECKING IS DONE ON THE TABLE, AS IT'S MEANT TO
C     BE STATIC AND CREATED AT CODE DEVELOPMENT TIME.
C   - THE MADISCOM PROVIDER ARRAYS (NPVD, PVDNAME, ETC.) HAVE WISDOM
C     PROVIDERS IN ROW 1, HYDRO PROVIDERS IN ROW 2, MAP PROVIDERS
C     IN ROW 3, RDMTR PROVIDERS IN ROW 4, AND WISDOM PROVIDERS IN ROW 5.
C
C ATTRIBUTES:
C   LANGUAGE: FORTRAN-77 + EXTENSIONS
C   MACHINE:  UNIX
C$$$

      SUBROUTINE MWISDOMINIT(WISDOMTBL,STATUS)

C     INCLUDES AND COMMONS
C     ------------------------------------------------------------------
      INCLUDE 'IMPLICIT'
      INCLUDE 'MADISCON'
      INCLUDE 'MADISCOM'

C     ------------------------------------------------------------------
C     ARGUMENTS
C     ------------------------------------------------------------------
      CHARACTER*(*) WISDOMTBL
      INTEGER       STATUS

C     ------------------------------------------------------------------
C     LOCAL
C     ------------------------------------------------------------------
      INTEGER       I

C     ---------------------------------------------------------------
C     INITIALIZE MADISCOM VARIABLES. 
C     ---------------------------------------------------------------
      WISDOMDSET_ENBL(1) = .TRUE.
      DO 1201 I = 1, MAX_SUBSRC_P
         PROVDR_ENBL(I,9) = .TRUE.
 1201 CONTINUE

      NNEWPVD(9) = 0
      ALL_ENBL(9) = .TRUE.

      WISDOMDSET_NAME(1) = 'WISDOM'

      LAST_WISDOM_ATIME = '         '

      TOTAL_STNS = 0
      DMTYPE = -1
      QCTYPE = 0

      MINBCK = 0
      MINFWD = 0
      RECWIN = 0

      WISDOM_INIT = INIT_P

C     ------------------------------------------------------------------
C     READ IN THE MADIS WISDOM TABLE (DEFINES VARIABLES AND DATASETS).
C     MWISDOMTBL WILL REPORT ANY ERRORS AND SET STATUS.
C     ------------------------------------------------------------------
      CALL MWISDOMTBL(WISDOMTBL,STATUS)
      IF(STATUS.NE.SUCCESS_P)RETURN


      RETURN
      END
C**---------------------------------------------------------------------
C**REQUIRED STANDARD FSL DISCLAIMER (NOVEMBER 2000)
C**---------------------------------------------------------------------
C**  OPEN SOURCE LICENSE/DISCLAIMER,  FORECAST SYSTEMS LABORATORY
C**  NOAA/OAR/FSL, 325 BROADWAY BOULDER, CO 80305
C**
C**  THIS SOFTWARE IS DISTRIBUTED UNDER THE OPEN SOURCE DEFINITION, 
C**  WHICH MAY BE FOUND AT http://www.opensource.org/osd.html.
C**
C**  IN PARTICULAR, REDISTRIBUTION AND USE IN SOURCE AND BINARY FORMS,
C**  WITH OR WITHOUT MODIFICATION, ARE PERMITTED PROVIDED THAT THE 
C**  FOLLOWING CONDITIONS ARE MET:
C**
C**  - REDISTRIBUTIONS OF SOURCE CODE MUST RETAIN THIS NOTICE, THIS LIST
C**    OF CONDITIONS AND THE FOLLOWING DISCLAIMER.
C**
C**  - REDISTRIBUTIONS IN BINARY FORM MUST PROVIDE ACCESS TO THIS 
C**    NOTICE, THIS LIST OF CONDITIONS AND THE FOLLOWING DISCLAIMER, AND
C**    THE UNDERLYING SOURCE CODE.
C**
C**  - ALL MODIFICATIONS TO THIS SOFTWARE MUST BE CLEARLY DOCUMENTED, 
C**    AND ARE SOLELY THE RESPONSIBILITY OF THE AGENT MAKING THE 
C**    MODIFICATIONS.
C**
C**  - IF SIGNIFICANT MODIFICATIONS OR ENHANCEMENTS ARE MADE TO THIS
C**    SOFTWARE, THE FSL SOFTWARE POLICY MANAGER 
C**    (softwaremgr.fsl@noaa.gov) BE NOTIFIED.
C**
C**  THIS SOFTWARE AND ITS DOCUMENTATION ARE IN THE PUBLIC DOMAIN AND 
C**  ARE FURNISHED "AS IS."  THE AUTHORS, THE UNITED STATES GOVERNMENT,
C**  ITS INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO 
C**  WARRANTY, EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE
C**  AND DOCUMENTATION FOR ANY PURPOSE.  THEY ASSUME NO RESPONSIBILITY 
C**  (1) FOR THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO 
C**  PROVIDE TECHNICAL SUPPORT TO USERS.
C**---------------------------------------------------------------------
